package net.javase.db.utils;

/**
 * StrUtil
 *
 * @author Frank
 */
public class StrUtil {

    /**
     * 判断字符串是否为空
     *
     * @param str 字符串
     * @return true | false
     */
    public static boolean isBlank(String str) {
        return str == null || str.length() == 0 || str.trim().length() == 0;
    }

    /**
     * 字符串是否不为null或者''
     *
     * @param str 字符串
     * @return true | false
     */
    public static boolean notBlank(String str) {
        return !isBlank(str);
    }

    /**
     * 驼峰转下划线
     *
     * @param str 驼峰字符串
     * @return 下划线字符串
     */
    public static String camelToUnderscore(String str) {
        if (str == null || str.isEmpty()) {
            return str;
        }
        StringBuilder result = new StringBuilder();
        char[] chars = str.toCharArray();
        for (int i = 0; i < chars.length; i++) {
            char ch = chars[i];
            if (i == 0) {
                result.append(Character.toLowerCase(ch));
                continue;
            }
            if (Character.isUpperCase(ch)) {
                result.append("_").append(Character.toLowerCase(ch));
            } else if (Character.isDigit(ch)) {
                result.append("_").append(ch);
            } else {
                result.append(ch);
            }
        }
        return result.toString();
    }

    /**
     * 下划线转驼峰
     *
     * @param underLineStr 下划线字符串
     * @return 驼峰字符串
     */
    public static String underlineToCamel(String underLineStr) {
        StringBuilder result = new StringBuilder();
        // 标记当前字符是否为下划线后的第一个字符
        boolean flag = false;
        // 遍历字符串，将下划线后的第一个字符转换成大写字母
        for (int i = 0; i < underLineStr.length(); i++) {
            char currentChar = underLineStr.charAt(i);
            if (currentChar == '_') {
                flag = true;
            } else {
                if (flag) {
                    result.append(Character.toUpperCase(currentChar));
                    flag = false;
                } else {
                    result.append(Character.toLowerCase(currentChar));
                }
            }
        }
        return result.toString();
    }

}
